@@ -1,50 +1,46 @@
-﻿define(['imageLoader', 'layoutManager', 'jQuery'], function (imageLoader, layoutManager, $) {
+﻿define(['imageLoader', 'layoutManager', 'viewManager', 'navdrawer', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, navdrawer, libraryBrowser, appHost) {
 
-    var mainDrawerPanel = document.querySelector('.mainDrawerPanel');
+    var navDrawerElement = document.querySelector('.mainDrawer');
+    var navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
+    var navDrawerInstance;
 
     function renderHeader() {
 
         var html = '';
 
         html += '<div class="primaryIcons">';
-        var backIcon = browserInfo.safari ? 'chevron-left' : 'arrow-back';
+        var backIcon = browserInfo.safari ? 'chevron_left' : '&#xE5C4;';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide"><iron-icon icon="' + backIcon + '"></iron-icon></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide autoSize"><i class="md-icon">' + backIcon + '</i></button>';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft"><iron-icon icon="menu"></iron-icon></button>';
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft"><iron-icon icon="menu"></iron-icon></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">menu</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">home</i></button>';
 
         html += '<div class="libraryMenuButtonText headerButton">' + Globalize.translate('ButtonHome') + '</div>';
 
         html += '<div class="viewMenuSecondary">';
 
         html += '<span class="headerSelectedPlayer"></span>';
-        html += '<button is="paper-icon-button-light" class="btnCast headerButton headerButtonRight hide"><iron-icon icon="cast"></iron-icon></button>';
+        html += '<button is="paper-icon-button-light" class="btnCast headerButton headerButtonRight hide autoSize"><i class="md-icon">cast</i></button>';
 
         if (AppInfo.enableSearchInTopMenu) {
-            html += '<button type="button" is="paper-icon-button-light" class=headerButton headerButtonRight headerSearchButton hide" onclick="Search.showSearchPanel();"><iron-icon icon="search"></iron-icon></button>';
-            html += '<div class="viewMenuSearch hide">';
-            html += '<form class="viewMenuSearchForm">';
-            html += '<input type="text" data-role="none" data-type="search" class="headerSearchInput" autocomplete="off" spellcheck="off" />';
-            html += '<button is="paper-icon-button-light" class="btnCloseSearch"><iron-icon icon="close"></iron-icon></button>';
-            html += '</form>';
-            html += '</div>';
+            html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonRight headerSearchButton hide autoSize"><i class="md-icon">search</i></button>';
         }
 
-        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerVoiceButton hide"><iron-icon icon="mic"></iron-icon></button>';
+        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerVoiceButton hide autoSize"><i class="md-icon">mic</i></button>';
 
-        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight btnNotifications clearButton"><div class="btnNotificationsInner">0</div></button>';
+        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight btnNotifications"><div class="btnNotificationsInner">0</div></button>';
 
-        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerUserButton"><iron-icon icon="person"></iron-icon></button>';
+        html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerUserButton autoSize"><i class="md-icon">person</i></button>';
 
         if (!browserInfo.mobile && !Dashboard.isConnectMode()) {
-            html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight dashboardEntryHeaderButton" onclick="return LibraryMenu.onSettingsClicked(event);"><iron-icon icon="settings"></iron-icon></button>';
+            html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight dashboardEntryHeaderButton autoSize" onclick="return LibraryMenu.onSettingsClicked(event);"><i class="md-icon">settings</i></button>';
         }
 
         html += '</div>';
         html += '</div>';
 
-        html += '<div class="viewMenuBarTabs hiddenScrollX">';
+        html += '<div class="viewMenuBarTabs">';
         html += '</div>';
 
         var viewMenuBar = document.createElement('div');
@@ -91,7 +87,7 @@
                 }
 
                 if (headerUserButton) {
-                    updateHeaderUserButton(headerUserButton, url, null);
+                    updateHeaderUserButton(headerUserButton, url);
                     hasImage = true;
                 }
             }
@@ -99,7 +95,7 @@
 
         if (headerUserButton && !hasImage) {
 
-            updateHeaderUserButton(headerUserButton, null, 'person');
+            updateHeaderUserButton(headerUserButton, null);
         }
         if (user) {
             updateLocalUser(user.localUser);
@@ -108,16 +104,16 @@
         requiresUserRefresh = false;
     }
 
-    function updateHeaderUserButton(headerUserButton, src, icon) {
+    function updateHeaderUserButton(headerUserButton, src) {
 
         if (src) {
             headerUserButton.classList.add('headerUserButtonRound');
+            headerUserButton.classList.remove('autoSize');
             headerUserButton.innerHTML = '<img src="' + src + '" />';
-        } else if (icon) {
-            headerUserButton.classList.remove('headerUserButtonRound');
-            headerUserButton.innerHTML = '<iron-icon icon="' + icon + '"></iron-icon>';
         } else {
             headerUserButton.classList.remove('headerUserButtonRound');
+            headerUserButton.classList.add('autoSize');
+            headerUserButton.innerHTML = '<i class="md-icon">person</i>';
         }
     }
 
@@ -144,9 +140,9 @@
                 }
             }
 
-            require(['voice/voice'], function (voice) {
+            require(['apphost'], function (apphost) {
 
-                if (voice.isSupported()) {
+                if (apphost.supports('voiceinput')) {
                     header.querySelector('.headerVoiceButton').classList.remove('hide');
                 } else {
                     header.querySelector('.headerVoiceButton').classList.add('hide');
@@ -168,68 +164,22 @@
     }
 
     function showVoice() {
-        require(['voice/voice'], function (voice) {
-            voice.startListening();
+        require(['voiceDialog'], function (voiceDialog) {
+            voiceDialog.showDialog();
         });
     }
 
+    function showSearch() {
+        Dashboard.navigate('search.html');
+    }
+
     function onHeaderUserButtonClick(e) {
         Dashboard.showUserFlyout(e.target);
     }
 
     function onHeaderAppsButtonClick() {
 
-        require(['dialogHelper'], function (dialogHelper) {
-
-            var dlg = dialogHelper.createDialog({
-                removeOnClose: true,
-                modal: false,
-                autoFocus: false,
-                entryAnimationDuration: 160,
-                exitAnimationDuration: 160,
-                enableHistory: false
-            });
-
-            dlg.classList.add('ui-body-a');
-            dlg.classList.add('background-theme-a');
-            dlg.classList.add('adminAppsMenu');
-
-            var html = '';
-
-            html += '<div class="adminAppsMenuRow">';
-
-            html += '<a class="adminAppsButton" href="home.html">';
-            html += '<button is="paper-icon-button-light"><iron-icon icon="home"></iron-icon></button>';
-            html += '<div>' + Globalize.translate('ButtonHome') + '</div>';
-            html += '</a>';
-
-            html += '</div>';
-
-            html += '<div class="adminAppsMenuRow">';
-
-            html += '<a class="adminAppsButton" href="edititemmetadata.html">';
-            html += '<button is="paper-icon-button-light"><iron-icon icon="mode-edit"></iron-icon></button>';
-            html += '<div>' + Globalize.translate('ButtonMetadataManager') + '</div>';
-            html += '</a>';
-            html += '<a class="adminAppsButton" href="reports.html">';
-            html += '<button is="paper-icon-button-light"><iron-icon icon="insert-chart"></iron-icon></button>';
-            html += '<div>' + Globalize.translate('ButtonReports') + '</div>';
-            html += '</a>';
-
-            html += '</div>';
-
-            dlg.innerHTML = html;
-            document.body.appendChild(dlg);
-
-            dlg.addEventListener('click', function (e) {
-                var link = parentWithTag(e.target, 'A');
-                if (link) {
-                    dialogHelper.close(dlg);
-                }
-            });
-            dialogHelper.open(dlg);
-
-        });
+        Dashboard.navigate('home.html');
     }
 
     function bindMenuEvents() {
@@ -250,6 +200,11 @@
             headerVoiceButton.addEventListener('click', showVoice);
         }
 
+        var headerSearchButton = document.querySelector('.headerSearchButton');
+        if (headerSearchButton) {
+            headerSearchButton.addEventListener('click', showSearch);
+        }
+
         var headerUserButton = document.querySelector('.headerUserButton');
         if (headerUserButton) {
             headerUserButton.addEventListener('click', onHeaderUserButtonClick);
@@ -270,7 +225,7 @@
 
     function getItemHref(item, context) {
 
-        return LibraryBrowser.getHref(item, context);
+        return libraryBrowser.getHref(item, context);
     }
 
     var requiresUserRefresh = true;
@@ -278,17 +233,16 @@
 
     function toggleMainDrawer() {
 
-        if (mainDrawerPanel.selected == 'drawer') {
-            closeMainDrawer(mainDrawerPanel);
+        if (navDrawerInstance.isVisible) {
+            closeMainDrawer();
         } else {
-            openMainDrawer(mainDrawerPanel);
+            openMainDrawer();
         }
     }
 
-    function openMainDrawer(drawerPanel) {
+    function openMainDrawer() {
 
-        drawerPanel = drawerPanel || document.querySelector('.mainDrawerPanel');
-        drawerPanel.openDrawer();
+        navDrawerInstance.open();
         lastOpenTime = new Date().getTime();
     }
 
@@ -298,16 +252,13 @@
             document.body.classList.add('bodyWithPopupOpen');
         }
     }
-    function closeMainDrawer(drawerPanel) {
+    function closeMainDrawer() {
 
-        drawerPanel = drawerPanel || document.querySelector('.mainDrawerPanel');
-        drawerPanel.closeDrawer();
+        navDrawerInstance.close();
     }
     function onMainDrawerSelect(e) {
 
-        var drawer = e.target;
-
-        if (drawer.selected != 'drawer') {
+        if (!navDrawerInstance.isVisible) {
             document.body.classList.remove('bodyWithPopupOpen');
         } else {
             onMainDrawerOpened();
@@ -323,11 +274,11 @@
         var homeHref = window.ApiClient ? 'home.html' : 'selectserver.html?showuser=1';
 
         html += '<a class="lnkMediaFolder sidebarLink" href="' + homeHref + '" onclick="return LibraryMenu.onLinkClicked(event, this);">';
-        html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.6em 0 1.5em;display:inline-block;"></div>';
+        html += '<div style="background-image:url(\'css/images/mblogoicon.png\');width:' + 28 + 'px;height:' + 28 + 'px;background-size:contain;background-repeat:no-repeat;background-position:center center;border-radius:1000px;vertical-align:middle;margin:0 1.25em 0 1.55em;display:inline-block;"></div>';
         html += Globalize.translate('ButtonHome');
         html += '</a>';
 
-        html += '<a class="sidebarLink lnkMediaFolder" data-itemid="remote" href="nowplaying.html" onclick="return LibraryMenu.onLinkClicked(event, this);"><iron-icon icon="tablet-android" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonRemote') + '</span></a>';
+        html += '<a class="sidebarLink lnkMediaFolder" data-itemid="remote" href="nowplaying.html" onclick="return LibraryMenu.onLinkClicked(event, this);"><i class="md-icon sidebarLinkIcon">tablet_android</i><span class="sidebarLinkText">' + Globalize.translate('ButtonRemote') + '</span></a>';
 
         html += '<div class="sidebarDivider"></div>';
 
@@ -344,11 +295,11 @@
             html += Globalize.translate('HeaderAdmin');
             html += '</div>';
 
-            html += '<a class="sidebarLink lnkMediaFolder lnkManageServer" data-itemid="dashboard" href="#"><iron-icon icon="dashboard" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonManageServer') + '</span></a>';
-            html += '<a class="sidebarLink lnkMediaFolder editorViewMenu" data-itemid="editor" onclick="return LibraryMenu.onLinkClicked(event, this);" href="edititemmetadata.html"><iron-icon icon="mode-edit" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonMetadataManager') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder lnkManageServer" data-itemid="dashboard" href="#"><i class="md-icon sidebarLinkIcon">dashboard</i><span class="sidebarLinkText">' + Globalize.translate('ButtonManageServer') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder editorViewMenu" data-itemid="editor" onclick="return LibraryMenu.onLinkClicked(event, this);" href="edititemmetadata.html"><i class="md-icon sidebarLinkIcon">mode_edit</i><span class="sidebarLinkText">' + Globalize.translate('MetadataManager') + '</span></a>';
 
             if (!browserInfo.mobile) {
-                html += '<a class="sidebarLink lnkMediaFolder" data-itemid="reports" onclick="return LibraryMenu.onLinkClicked(event, this);" href="reports.html"><iron-icon icon="insert-chart" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonReports') + '</span></a>';
+                html += '<a class="sidebarLink lnkMediaFolder" data-itemid="reports" onclick="return LibraryMenu.onLinkClicked(event, this);" href="reports.html"><i class="md-icon sidebarLinkIcon">insert_chart</i><span class="sidebarLinkText">' + Globalize.translate('ButtonReports') + '</span></a>';
             }
             html += '</div>';
         }
@@ -358,60 +309,43 @@
         html += '<div class="sidebarDivider"></div>';
 
         if (user.localUser && (AppInfo.isNativeApp && browserInfo.android)) {
-            html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html?userId=' + user.localUser.Id + '"><iron-icon icon="settings" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html?userId=' + user.localUser.Id + '"><i class="md-icon sidebarLinkIcon">settings</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
         }
 
-        html += '<a class="sidebarLink lnkMediaFolder lnkMySync" data-itemid="mysync" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html"><iron-icon icon="sync" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSync') + '</span></a>';
+        html += '<a class="sidebarLink lnkMediaFolder lnkManageOffline" data-itemid="manageoffline" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html?mode=offline"><i class="md-icon sidebarLinkIcon">file_download</i><span class="sidebarLinkText">' + Globalize.translate('ManageOfflineDownloads') + '</span></a>';
+
+        html += '<a class="sidebarLink lnkMediaFolder lnkSyncToOtherDevices" data-itemid="syncotherdevices" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html"><i class="md-icon sidebarLinkIcon">sync</i><span class="sidebarLinkText">' + Globalize.translate('SyncToOtherDevices') + '</span></a>';
 
         if (Dashboard.isConnectMode()) {
-            html += '<a class="sidebarLink lnkMediaFolder" data-itemid="selectserver" onclick="return LibraryMenu.onLinkClicked(event, this);" href="selectserver.html?showuser=1"><iron-icon icon="wifi" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSelectServer') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder" data-itemid="selectserver" onclick="return LibraryMenu.onLinkClicked(event, this);" href="selectserver.html?showuser=1"><i class="md-icon sidebarLinkIcon">wifi</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSelectServer') + '</span></a>';
         }
 
         if (user.localUser) {
-            html += '<a class="sidebarLink lnkMediaFolder" data-itemid="logout" onclick="return LibraryMenu.onLogoutClicked(this);" href="#"><iron-icon icon="lock" class="sidebarLinkIcon"></iron-icon><span class="sidebarLinkText">' + Globalize.translate('ButtonSignOut') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder" data-itemid="logout" onclick="return LibraryMenu.onLogoutClicked(this);" href="#"><i class="md-icon sidebarLinkIcon">lock</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSignOut') + '</span></a>';
         }
 
         html += '</div>';
 
-        var drawer = mainDrawerPanel.querySelector('.mainDrawer');
+        navDrawerScrollContainer.innerHTML = html;
 
-        drawer.innerHTML = html;
-
-        var lnkManageServer = drawer.querySelector('.lnkManageServer');
+        var lnkManageServer = navDrawerScrollContainer.querySelector('.lnkManageServer');
         if (lnkManageServer) {
             lnkManageServer.addEventListener('click', onManageServerClicked);
         }
-
-        require(['imageLoader'], function (imageLoader) {
-            imageLoader.fillImages(mainDrawerPanel.getElementsByClassName('lazy'));
-        });
     }
 
     function refreshDashboardInfoInDrawer(page, user) {
 
-        if (!mainDrawerPanel.querySelector('.adminDrawerLogo')) {
+        if (!navDrawerScrollContainer.querySelector('.adminDrawerLogo')) {
             createDashboardMenu(page);
         } else {
             updateDashboardMenuSelectedItem();
         }
     }
 
-    function parentWithTag(elem, tagName) {
-
-        while (elem.tagName != tagName) {
-            elem = elem.parentNode;
-
-            if (!elem) {
-                return null;
-            }
-        }
-
-        return elem;
-    }
-
     function updateDashboardMenuSelectedItem() {
 
-        var links = mainDrawerPanel.querySelectorAll('.sidebarLink');
+        var links = navDrawerScrollContainer.querySelectorAll('.sidebarLink');
 
         for (var i = 0, length = links.length; i < length; i++) {
             var link = links[i];
@@ -420,7 +354,7 @@
 
             var pageIds = link.getAttribute('data-pageids');
             if (pageIds) {
-                selected = pageIds.split(',').indexOf($.mobile.activePage.id) != -1
+                selected = pageIds.split(',').indexOf(viewManager.currentView().id) != -1
             }
 
             if (selected) {
@@ -428,6 +362,7 @@
 
                 var title = '';
 
+                link = link.querySelector('span') || link;
                 var secondaryTitle = (link.innerText || link.textContent).trim();
                 title += secondaryTitle;
 
@@ -452,7 +387,7 @@
 
         html = html.split('href=').join('onclick="return LibraryMenu.onLinkClicked(event, this);" href=');
 
-        mainDrawerPanel.querySelector('.mainDrawer').innerHTML = html;
+        navDrawerScrollContainer.innerHTML = html;
 
         updateDashboardMenuSelectedItem();
     }
@@ -481,7 +416,7 @@
                 if (view.CollectionType == 'livetv') {
 
                     view.ImageTags = {};
-                    view.icon = 'live-tv';
+                    view.icon = 'live_tv';
                     view.onclick = "LibraryBrowser.showTab('livetv.html', 0);";
 
                     var guideView = Object.assign({}, view);
@@ -514,15 +449,22 @@
 
         if (!user) {
 
-            showBySelector('.lnkMySync', false);
+            showBySelector('.lnkManageOffline', false);
+            showBySelector('.lnkSyncToOtherDevices', false);
             showBySelector('.userMenuOptions', false);
             return;
         }
 
         if (user.Policy.EnableSync) {
-            showBySelector('.lnkMySync', true);
+            showBySelector('.lnkSyncToOtherDevices', true);
         } else {
-            showBySelector('.lnkMySync', false);
+            showBySelector('.lnkSyncToOtherDevices', false);
+        }
+
+        if (user.Policy.EnableSync && appHost.supports('sync')) {
+            showBySelector('.lnkManageOffline', true);
+        } else {
+            showBySelector('.lnkManageOffline', false);
         }
 
         var userId = Dashboard.getCurrentUserId();
@@ -558,19 +500,19 @@
                 }
 
                 if (i.CollectionType == "photos") {
-                    icon = 'photo-library';
+                    icon = 'photo_library';
                     color = "#009688";
                 }
                 else if (i.CollectionType == "music" || i.CollectionType == "musicvideos") {
-                    icon = 'library-music';
+                    icon = 'library_music';
                     color = '#FB8521';
                 }
                 else if (i.CollectionType == "books") {
-                    icon = 'library-books';
+                    icon = 'library_books';
                     color = "#1AA1E1";
                 }
                 else if (i.CollectionType == "playlists") {
-                    icon = 'view-list';
+                    icon = 'view_list';
                     color = "#795548";
                 }
                 else if (i.CollectionType == "games") {
@@ -578,7 +520,7 @@
                     color = "#F44336";
                 }
                 else if (i.CollectionType == "movies") {
-                    icon = 'video-library';
+                    icon = 'video_library';
                     color = '#CE5043';
                 }
                 else if (i.CollectionType == "channels" || i.Type == 'Channel') {
@@ -590,14 +532,14 @@
                     color = "#4CAF50";
                 }
                 else if (i.CollectionType == "livetv") {
-                    icon = 'live-tv';
+                    icon = 'live_tv';
                     color = "#293AAE";
                 }
 
                 icon = i.icon || icon;
 
                 var onclick = i.onclick ? ' function(){' + i.onclick + '}' : 'null';
-                return '<a data-itemid="' + itemId + '" class="lnkMediaFolder sidebarLink" onclick="return LibraryMenu.onLinkClicked(event, this, ' + onclick + ');" href="' + getItemHref(i, i.CollectionType) + '"><iron-icon icon="' + icon + '" class="sidebarLinkIcon" style="color:' + color + '"></iron-icon><span class="sectionName">' + i.Name + '</span></a>';
+                return '<a data-itemid="' + itemId + '" class="lnkMediaFolder sidebarLink" onclick="return LibraryMenu.onLinkClicked(event, this, ' + onclick + ');" href="' + getItemHref(i, i.CollectionType) + '"><i class="md-icon sidebarLinkIcon" style="color:' + color + '">' + icon + '</i><span class="sectionName">' + i.Name + '</span></a>';
 
             }).join('');
 
@@ -624,6 +566,11 @@
         return getParameterByName('topParentId') || null;
     }
 
+    function getNavigateDelay() {
+        // On mobile devices don't navigate until after the closing animation has completed or it may stutter
+        return browserInfo.mobile ? 320 : 200;;
+    }
+
     window.LibraryMenu = {
         getTopParentId: getTopParentId,
 
@@ -639,8 +586,6 @@
                 setTimeout(function () {
                     closeMainDrawer();
 
-                    // On mobile devices don't navigate until after the closing animation has completed or it may stutter
-                    var delay = browserInfo.mobile ? 350 : 200;
 
                     setTimeout(function () {
                         if (action) {
@@ -648,7 +593,7 @@
                         } else {
                             Dashboard.navigate(link.href);
                         }
-                    }, delay);
+                    }, getNavigateDelay());
 
                 }, 50);
             }
@@ -664,12 +609,9 @@
 
                 closeMainDrawer();
 
-                // On mobile devices don't navigate until after the closing animation has completed or it may stutter
-                var delay = browserInfo.mobile ? 350 : 200;
-
                 setTimeout(function () {
                     Dashboard.logout();
-                }, delay);
+                }, getNavigateDelay());
             }
 
             return false;
@@ -697,7 +639,7 @@
             if (!type) {
                 if (LibraryMenu.tabType) {
 
-                    mainDrawerPanel.classList.remove('withTallToolbar');
+                    document.body.classList.remove('withTallToolbar');
                     viewMenuBarTabs = document.querySelector('.viewMenuBarTabs');
                     viewMenuBarTabs.innerHTML = '';
                     viewMenuBarTabs.classList.add('hide');
@@ -712,43 +654,49 @@
                 viewMenuBarTabs.classList.remove('hide');
             }
 
-            if (LibraryMenu.tabType != type) {
+            require(['emby-tabs', 'emby-button'], function () {
+                if (LibraryMenu.tabType != type) {
 
-                require(['paper-tabs'], function () {
+                    var index = 0;
 
-                    var noInk = browserInfo.animate ? '' : ' noink';
+                    viewMenuBarTabs.innerHTML = '<div is="emby-tabs"><div class="emby-tabs-slider">' + builder().map(function (t) {
 
-                    viewMenuBarTabs.innerHTML = '<paper-tabs selected="' + selectedIndex + '" hidescrollbuttons ' + noInk + '>' + builder().map(function (t) {
+                        var tabClass = selectedIndex == index ? 'emby-tab-button emby-tab-button-active' : 'emby-tab-button';
 
-                        return '<paper-tab link><a class="clearLink paperTabLink" href="' + t.href + '"><div>' + t.name + '</div></a></paper-tab>';
+                        var tabHtml = '<button onclick="Dashboard.navigate(this.getAttribute(\'data-href\'));" data-href="' + t.href + '" is="emby-button" class="' + tabClass + '" data-index="' + index + '"><div class="emby-button-foreground">' + t.name + '</div></button>';
+                        index++;
+                        return tabHtml;
 
-                    }).join('') + '</paper-tabs>';
-                    mainDrawerPanel.classList.add('withTallToolbar');
+                    }).join('') + '</div></div>';
+
+                    document.body.classList.add('withTallToolbar');
                     LibraryMenu.tabType = type;
-                });
-                return;
-            }
+                    return;
+                }
 
-            viewMenuBarTabs.querySelector('paper-tabs').selected = selectedIndex;
-            LibraryMenu.tabType = type;
+                viewMenuBarTabs.querySelector('[is="emby-tabs"]').selectedIndex(selectedIndex);
+
+                LibraryMenu.tabType = type;
+            });
         },
 
         setTitle: function (title) {
 
             var html = title;
 
-            if (window.$ && $.mobile) {
-                var page = $.mobile.activePage;
-                if (page) {
-                    var helpUrl = page.getAttribute('data-helpurl');
+            var page = viewManager.currentView();
+            if (page) {
+                var helpUrl = page.getAttribute('data-helpurl');
 
-                    if (helpUrl) {
-                        html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><paper-button class="accent" style="margin:0;font-weight:normal;font-size:13px;padding:.25em;display:flex;align-items:center;"><iron-icon icon="info"></iron-icon><span>' + Globalize.translate('ButtonHelp') + '</span></paper-button></a>';
-                    }
+                if (helpUrl) {
+                    html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><button is="emby-button" type="button" class="accent" style="margin:0;font-weight:normal;font-size:14px;padding:.25em;display:block;align-items:center;"><i class="md-icon">info</i><span>' + Globalize.translate('ButtonHelp') + '</span></button></a>';
                 }
             }
 
-            document.querySelector('.libraryMenuButtonText').innerHTML = html;
+            var libraryMenuButtonText = document.querySelector('.libraryMenuButtonText');
+            if (libraryMenuButtonText) {
+                libraryMenuButtonText.innerHTML = html;
+            }
         },
 
         setBackButtonVisible: function (visible) {
@@ -804,14 +752,14 @@
 
         if (info.isLocalPlayer) {
 
-            btnCast.querySelector('iron-icon').icon = 'cast';
+            btnCast.querySelector('i').innerHTML = 'cast';
             btnCast.classList.remove('btnActiveCast');
 
             context.querySelector('.headerSelectedPlayer').innerHTML = '';
 
         } else {
 
-            btnCast.querySelector('iron-icon').icon = 'cast-connected';
+            btnCast.querySelector('i').icon = 'cast_connected';
             btnCast.classList.add('btnActiveCast');
             context.querySelector('.headerSelectedPlayer').innerHTML = info.deviceName || info.name;
         }
@@ -849,7 +797,12 @@
             else if (isReportsPage && itemId == 'reports') {
                 lnkMediaFolder.classList.add('selectedMediaFolder');
             }
-            else if (isMySyncPage && itemId == 'mysync') {
+            else if (isMySyncPage && itemId == 'manageoffline' && window.location.href.toString().indexOf('mode=offline') != -1) {
+
+                lnkMediaFolder.classList.add('selectedMediaFolder');
+            }
+            else if (isMySyncPage && itemId == 'syncotherdevices' && window.location.href.toString().indexOf('mode=offline') == -1) {
+
                 lnkMediaFolder.classList.add('selectedMediaFolder');
             }
             else if (id && itemId == id) {
@@ -861,33 +814,6 @@
         }
     }
 
-    function updateTabLinks(page) {
-
-        var elems = page.querySelectorAll('.scopedLibraryViewNav a');
-
-        var id = page.classList.contains('liveTvPage') || page.classList.contains('channelsPage') || page.classList.contains('metadataEditorPage') || page.classList.contains('reportsPage') || page.classList.contains('mySyncPage') || page.classList.contains('allLibraryPage') ?
-            '' :
-            getTopParentId() || '';
-
-        if (!id) {
-            return;
-        }
-
-        for (i = 0, length = elems.length; i < length; i++) {
-
-            var lnk = elems[i];
-            var src = lnk.href;
-
-            if (src.indexOf('#') != -1) {
-                continue;
-            }
-
-            src = replaceQueryString(src, 'topParentId', id);
-
-            lnk.href = src;
-        }
-    }
-
     function onWebSocketMessage(e, data) {
 
         var msg = data;
@@ -924,21 +850,6 @@
         }
     }
 
-    pageClassOn('pageinit', 'page', function () {
-
-        var page = this;
-
-        var isLibraryPage = page.classList.contains('libraryPage');
-
-        if (isLibraryPage) {
-
-            var navs = page.querySelectorAll('.libraryViewNav');
-            for (var i = 0, length = navs.length; i < length; i++) {
-                initHeadRoom(navs[i]);
-            }
-        }
-    });
-
     pageClassOn('pagebeforeshow', 'page', function (e) {
 
         var page = this;
@@ -956,20 +867,15 @@
 
         if (isDashboardPage) {
             refreshDashboardInfoInDrawer(page);
-            mainDrawerPanel.forceNarrow = false;
         } else {
-
-            if (mainDrawerPanel.classList.contains('adminDrawerPanel')) {
+            if (navDrawerElement.classList.contains('adminDrawer')) {
                 refreshLibraryDrawer();
             }
-
-            mainDrawerPanel.forceNarrow = true;
         }
 
         setDrawerClass(page);
 
         updateViewMenuBar(page);
-        updateTabLinks(page);
 
         if (!e.detail.isRestored) {
             // Scroll back up so in case vertical scroll was messed with
@@ -1044,18 +950,9 @@
             return;
         }
 
-        require(["headroom"], function () {
+        require(["headroom-window"], function (headroom) {
 
-            // construct an instance of Headroom, passing the element
-            var headroom = new Headroom(elem, {
-                // or scroll tolerance per direction
-                tolerance: {
-                    down: 40,
-                    up: 0
-                }
-            });
-            // initialise
-            headroom.init();
+            headroom.add(elem);
         });
     }
 
@@ -1075,9 +972,7 @@
         var admin = false;
 
         if (!page) {
-            if (window.$ && window.$.mobile) {
-                page = $.mobile.activePage;
-            }
+            page = viewManager.currentView();
         }
 
         if (page && page.classList.contains('type-interior')) {
@@ -1085,11 +980,11 @@
         }
 
         if (admin) {
-            mainDrawerPanel.classList.add('adminDrawerPanel');
-            mainDrawerPanel.classList.remove('darkDrawerPanel');
+            navDrawerElement.classList.add('adminDrawer');
+            navDrawerElement.classList.remove('darkDrawer');
         } else {
-            mainDrawerPanel.classList.add('darkDrawerPanel');
-            mainDrawerPanel.classList.remove('adminDrawerPanel');
+            navDrawerElement.classList.add('darkDrawer');
+            navDrawerElement.classList.remove('adminDrawer');
         }
     }
 
@@ -1105,20 +1000,34 @@
         });
     }
 
-    mainDrawerPanel.addEventListener('iron-select', onMainDrawerSelect);
-    var headerCreated;
-    var userRequiresUpdateAfterHeader;
+    function getNavDrawerOptions() {
 
-    require(['paper-icon-button-light', 'emby-icons'], function () {
-        renderHeader();
-        headerCreated = true;
+        var drawerWidth = screen.availWidth - 50;
+        // At least 240
+        drawerWidth = Math.max(drawerWidth, 240);
+        // But not exceeding 280
+        drawerWidth = Math.min(drawerWidth, 280);
 
-        var user = userRequiresUpdateAfterHeader;
-        if (user) {
-            updateUserInHeader(user);
+        var disableEdgeSwipe = false;
+
+        if (browserInfo.safari) {
+            disableEdgeSwipe = true;
         }
-        userRequiresUpdateAfterHeader = null;
-    });
+
+        // Default is 600px
+        //drawer.responsiveWidth = '640px';
+
+        return {
+            target: navDrawerElement,
+            onChange: onMainDrawerSelect,
+            width: drawerWidth,
+            disableEdgeSwipe: disableEdgeSwipe
+        };
+    }
+
+    navDrawerInstance = new navdrawer(getNavDrawerOptions());
+    navDrawerElement.classList.remove('hide');
+    renderHeader();
 
     Events.on(ConnectionManager, 'apiclientcreated', function (e, apiClient) {
         initializeApiClient(apiClient);
@@ -1128,12 +1037,7 @@
         setDrawerClass();
         ConnectionManager.user(ConnectionManager.getApiClient(user.ServerId)).then(function (user) {
             refreshLibraryDrawer(user);
-
-            if (headerCreated) {
-                updateUserInHeader(user);
-            } else {
-                userRequiresUpdateAfterHeader = user;
-            }
+            updateUserInHeader(user);
         });
     });
 
@@ -1142,4 +1046,12 @@
 
     setDrawerClass();
 
+    //require(['appfooter'], function (appfooter) {
+    //    var footer = new appfooter({});
+    //    require(['dockedtabs'], function (dockedtabs) {
+    //        new dockedtabs({
+    //            appFooter: footer
+    //        });
+    //    });
+    //});
 });
\ No newline at end of file
