@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['cardBuilder', 'emby-itemscontainer'], function (cardBuilder) {
 
     return function (view, params, tabContent) {
 
@@ -15,7 +15,8 @@
                     query: {
                         StartIndex: 0,
                         EnableFavoriteSorting: true,
-                        Limit: LibraryBrowser.getDefaultPageSize()
+                        Limit: LibraryBrowser.getDefaultPageSize(),
+                        Fields: "PrimaryImageAspectRatio"
                     }
                 };
 
@@ -39,7 +40,7 @@
 
         function getChannelsHtml(channels) {
 
-            return LibraryBrowser.getPosterViewHtml({
+            return cardBuilder.getCardsHtml({
                 items: channels,
                 shape: "square",
                 showTitle: true,
@@ -53,14 +54,14 @@
 
             var query = getQuery(context);
 
-            $('.listTopPaging', context).html(LibraryBrowser.getQueryPagingHtml({
+            context.querySelector('.paging').innerHTML = LibraryBrowser.getQueryPagingHtml({
                 startIndex: query.StartIndex,
                 limit: query.Limit,
                 totalRecordCount: result.TotalRecordCount,
                 showLimit: false,
                 updatePageSizeSetting: false,
-                filterButton: true
-            }));
+                filterButton: false
+            });
 
             var html = getChannelsHtml(result.Items);
 
@@ -68,19 +69,28 @@
             elem.innerHTML = html;
             ImageLoader.lazyChildren(elem);
 
-            $('.btnNextPage', context).on('click', function () {
+            var i, length;
+            var elems;
+
+            function onNextPageClick() {
                 query.StartIndex += query.Limit;
                 reloadItems(context);
-            });
+            }
 
-            $('.btnPreviousPage', context).on('click', function () {
+            function onPreviousPageClick() {
                 query.StartIndex -= query.Limit;
                 reloadItems(context);
-            });
+            }
 
-            $('.btnFilter', context).on('click', function () {
-                showFilterMenu(context);
-            });
+            elems = context.querySelectorAll('.btnNextPage');
+            for (i = 0, length = elems.length; i < length; i++) {
+                elems[i].addEventListener('click', onNextPageClick);
+            }
+
+            elems = context.querySelectorAll('.btnPreviousPage');
+            for (i = 0, length = elems.length; i < length; i++) {
+                elems[i].addEventListener('click', onPreviousPageClick);
+            }
 
             LibraryBrowser.saveQueryValues(getSavedQueryKey(context), query);
         }
@@ -118,6 +128,10 @@
             });
         }
 
+        tabContent.querySelector('.btnFilter').addEventListener('click', function () {
+            showFilterMenu(tabContent);
+        });
+
         self.renderTab = function () {
 
             reloadItems(tabContent);
