@@ -265,10 +265,6 @@
                         name: Globalize.translate('OptionParentalRating'),
                         id: 'OfficialRating,SortName'
                     },
-                    {
-                        name: Globalize.translate('OptionPlayCount'),
-                        id: 'PlayCount,SortName'
-                    },
                     {
                         name: Globalize.translate('OptionReleaseDate'),
                         id: 'PremiereDate,SortName'
